=======
Credits
=======

Development Leads
-----------------

* Jeffrey S. Hazboun <jeffrey.hazboun@nanograv.org>
* Paul T. Baker <paul.baker@nanograv.org>
* Brent Shapiro-Albert <bjs0024@mix.wvu.edu>

Contributors
------------

* Joseph D. Romano
* Cassidy M. Wagner
* Amelia M. Henkel
* Paul Brook
* Michael T. Lam
* Jacob Hesse
